@@ -35,21 +35,21 @@ build_time_vars = {'ABIFLAGS': '',
            '-Werror=format-security         -fstack-clash-protection '
            '-fcf-protection         -fno-omit-frame-pointer '
            '-mno-omit-leaf-frame-pointer -g '
-           '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+           '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
            '-flto=auto -fno-semantic-interposition -fno-omit-frame-pointer '
            '-mno-omit-leaf-frame-pointer -march=x86-64 -mtune=generic -O2 '
            '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
            '-Wformat -Werror=format-security         -fstack-clash-protection '
            '-fcf-protection         -fno-omit-frame-pointer '
            '-mno-omit-leaf-frame-pointer -g '
-           '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+           '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
            '-flto=auto -fno-semantic-interposition -fno-omit-frame-pointer '
            '-mno-omit-leaf-frame-pointer -march=x86-64 -mtune=generic -O2 '
            '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
            '-Wformat -Werror=format-security         -fstack-clash-protection '
            '-fcf-protection         -fno-omit-frame-pointer '
            '-mno-omit-leaf-frame-pointer -g '
-           '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+           '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
            '-flto=auto -fno-semantic-interposition -fno-omit-frame-pointer '
            '-mno-omit-leaf-frame-pointer',
  'CFLAGSFORSHARED': '-fPIC',
@@ -65,7 +65,7 @@ build_time_vars = {'ABIFLAGS': '',
                      '-Werror=format-security         -fstack-clash-protection '
                      '-fcf-protection         -fno-omit-frame-pointer '
                      '-mno-omit-leaf-frame-pointer -g '
-                     '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                     '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                      '-flto=auto -fno-semantic-interposition '
                      '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer',
  'CONFIGURE_CFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
@@ -93,7 +93,7 @@ build_time_vars = {'ABIFLAGS': '',
                 '-Werror=format-security         -fstack-clash-protection '
                 '-fcf-protection         -fno-omit-frame-pointer '
                 '-mno-omit-leaf-frame-pointer -g '
-                '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                 '-flto=auto -fno-semantic-interposition '
                 "-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer' "
                 "'LDFLAGS=-Wl,-O1 -Wl,--sort-common -Wl,--as-needed "
@@ -102,9 +102,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/home/builder/.cache/aurutils/sync/python312/src/Python-3.12.11/coverage.info',
+ 'COVERAGE_INFO': '/home/build/git/python312/src/Python-3.12.12/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/home/builder/.cache/aurutils/sync/python312/src/Python-3.12.11/lcov-report',
+ 'COVERAGE_REPORT': '/home/build/git/python312/src/Python-3.12.12/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -358,7 +358,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
- 'HAVE_LIBB2': 1,
+ 'HAVE_LIBB2': 0,
  'HAVE_LIBDB': 0,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
@@ -690,7 +690,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-Werror=format-security         -fstack-clash-protection '
                     '-fcf-protection         -fno-omit-frame-pointer '
                     '-mno-omit-leaf-frame-pointer -g '
-                    '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                    '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                     '-flto=auto -fno-semantic-interposition '
                     '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                     '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
@@ -698,7 +698,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-Werror=format-security         -fstack-clash-protection '
                     '-fcf-protection         -fno-omit-frame-pointer '
                     '-mno-omit-leaf-frame-pointer -g '
-                    '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                    '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                     '-flto=auto -fno-semantic-interposition '
                     '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                     '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
@@ -706,7 +706,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-Werror=format-security         -fstack-clash-protection '
                     '-fcf-protection         -fno-omit-frame-pointer '
                     '-mno-omit-leaf-frame-pointer -g '
-                    '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                    '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                     '-flto=auto -fno-semantic-interposition '
                     '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                     '-flto -fuse-linker-plugin -ffat-lto-objects '
@@ -724,7 +724,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Werror=format-security         -fstack-clash-protection '
                    '-fcf-protection         -fno-omit-frame-pointer '
                    '-mno-omit-leaf-frame-pointer -g '
-                   '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                   '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                    '-flto=auto -fno-semantic-interposition '
                    '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                    '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
@@ -732,7 +732,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Werror=format-security         -fstack-clash-protection '
                    '-fcf-protection         -fno-omit-frame-pointer '
                    '-mno-omit-leaf-frame-pointer -g '
-                   '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                   '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                    '-flto=auto -fno-semantic-interposition '
                    '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                    '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
@@ -740,7 +740,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Werror=format-security         -fstack-clash-protection '
                    '-fcf-protection         -fno-omit-frame-pointer '
                    '-mno-omit-leaf-frame-pointer -g '
-                   '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                   '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                    '-flto=auto -fno-semantic-interposition '
                    '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -flto '
                    '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none '
@@ -761,7 +761,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-Werror=format-security         -fstack-clash-protection '
                     '-fcf-protection         -fno-omit-frame-pointer '
                     '-mno-omit-leaf-frame-pointer -g '
-                    '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                    '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                     '-flto=auto -fno-semantic-interposition '
                     '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                     '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
@@ -769,7 +769,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-Werror=format-security         -fstack-clash-protection '
                     '-fcf-protection         -fno-omit-frame-pointer '
                     '-mno-omit-leaf-frame-pointer -g '
-                    '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                    '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                     '-flto=auto -fno-semantic-interposition '
                     '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                     '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
@@ -777,7 +777,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-Werror=format-security         -fstack-clash-protection '
                     '-fcf-protection         -fno-omit-frame-pointer '
                     '-mno-omit-leaf-frame-pointer -g '
-                    '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                    '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                     '-flto=auto -fno-semantic-interposition '
                     '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                     '-flto -fuse-linker-plugin -ffat-lto-objects '
@@ -818,7 +818,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MKDIR_P': '/usr/bin/mkdir -p',
+ 'MKDIR_P': '/usr/sbin/mkdir -p',
  'MODBUILT_NAMES': 'array  _asyncio  _bisect  _contextvars  _csv  _heapq  '
                    '_json  _lsprof  _opcode  _pickle  _queue  _random  '
                    '_struct  _xxsubinterpreters  _xxinterpchannels  _zoneinfo  '
@@ -941,7 +941,7 @@ build_time_vars = {'ABIFLAGS': '',
                         './Modules/_blake2/impl/blake2s-round.h '
                         './Modules/_blake2/impl/blake2s.c '
                         './Modules/_blake2/blake2module.h ./Modules/hashlib.h',
- 'MODULE__BLAKE2_LDFLAGS': '-lb2',
+ 'MODULE__BLAKE2_LDFLAGS': '',
  'MODULE__BLAKE2_STATE': 'yes',
  'MODULE__BZ2_CFLAGS': '',
  'MODULE__BZ2_LDFLAGS': '-lbz2',
@@ -1156,7 +1156,7 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-clash-protection -fcf-protection         '
                              '-fno-omit-frame-pointer '
                              '-mno-omit-leaf-frame-pointer -g '
-                             '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                             '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                              '-flto=auto -fno-semantic-interposition '
                              '-fno-omit-frame-pointer '
                              '-mno-omit-leaf-frame-pointer -march=x86-64 '
@@ -1166,7 +1166,7 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-clash-protection -fcf-protection         '
                              '-fno-omit-frame-pointer '
                              '-mno-omit-leaf-frame-pointer -g '
-                             '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                             '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                              '-flto=auto -fno-semantic-interposition '
                              '-fno-omit-frame-pointer '
                              '-mno-omit-leaf-frame-pointer -march=x86-64 '
@@ -1176,7 +1176,7 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-clash-protection -fcf-protection         '
                              '-fno-omit-frame-pointer '
                              '-mno-omit-leaf-frame-pointer -g '
-                             '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                             '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                              '-flto=auto -fno-semantic-interposition '
                              '-fno-omit-frame-pointer '
                              '-mno-omit-leaf-frame-pointer -flto '
@@ -1194,21 +1194,21 @@ build_time_vars = {'ABIFLAGS': '',
               '-Werror=format-security         -fstack-clash-protection '
               '-fcf-protection         -fno-omit-frame-pointer '
               '-mno-omit-leaf-frame-pointer -g '
-              '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+              '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
               '-flto=auto -fno-semantic-interposition -fno-omit-frame-pointer '
               '-mno-omit-leaf-frame-pointer -march=x86-64 -mtune=generic -O2 '
               '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
               '-Wformat -Werror=format-security         '
               '-fstack-clash-protection -fcf-protection         '
               '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g '
-              '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+              '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
               '-flto=auto -fno-semantic-interposition -fno-omit-frame-pointer '
               '-mno-omit-leaf-frame-pointer -march=x86-64 -mtune=generic -O2 '
               '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
               '-Wformat -Werror=format-security         '
               '-fstack-clash-protection -fcf-protection         '
               '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g '
-              '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+              '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
               '-flto=auto -fno-semantic-interposition -fno-omit-frame-pointer '
               '-mno-omit-leaf-frame-pointer',
  'PY_CFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
@@ -1224,7 +1224,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Werror=format-security         -fstack-clash-protection '
                    '-fcf-protection         -fno-omit-frame-pointer '
                    '-mno-omit-leaf-frame-pointer -g '
-                   '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                   '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                    '-flto=auto -fno-semantic-interposition '
                    '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                    '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
@@ -1232,7 +1232,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Werror=format-security         -fstack-clash-protection '
                    '-fcf-protection         -fno-omit-frame-pointer '
                    '-mno-omit-leaf-frame-pointer -g '
-                   '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                   '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                    '-flto=auto -fno-semantic-interposition '
                    '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                    '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
@@ -1240,7 +1240,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Werror=format-security         -fstack-clash-protection '
                    '-fcf-protection         -fno-omit-frame-pointer '
                    '-mno-omit-leaf-frame-pointer -g '
-                   '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                   '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                    '-flto=auto -fno-semantic-interposition '
                    '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -flto '
                    '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none '
@@ -1280,7 +1280,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-fstack-clash-protection -fcf-protection         '
                         '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                         '-g '
-                        '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                        '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                         '-flto=auto -fno-semantic-interposition '
                         '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                         '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
@@ -1289,7 +1289,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-fstack-clash-protection -fcf-protection         '
                         '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                         '-g '
-                        '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                        '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                         '-flto=auto -fno-semantic-interposition '
                         '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                         '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
@@ -1298,7 +1298,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-fstack-clash-protection -fcf-protection         '
                         '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                         '-g '
-                        '-ffile-prefix-map=/home/builder/.cache/aurutils/sync/python312/src=/usr/src/debug/python312 '
+                        '-ffile-prefix-map=/home/build/git/python312/src=/usr/src/debug/python312 '
                         '-flto=auto -fno-semantic-interposition '
                         '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
                         '-flto -fuse-linker-plugin -ffat-lto-objects '
@@ -1319,7 +1319,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/builder/.cache/aurutils/sync/python312/src/Python-3.12.11',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/home/build/git/python312/src/Python-3.12.12',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1445,10 +1445,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/builder/.cache/aurutils/sync/python312/src/Python-3.12.11 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/build/git/python312/src/Python-3.12.12 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/builder/.cache/aurutils/sync/python312/src/Python-3.12.11 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/build/git/python312/src/Python-3.12.12 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1478,8 +1478,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/builder/.cache/aurutils/sync/python312/src/Python-3.12.11',
- 'abs_srcdir': '/home/builder/.cache/aurutils/sync/python312/src/Python-3.12.11',
+ 'abs_builddir': '/home/build/git/python312/src/Python-3.12.12',
+ 'abs_srcdir': '/home/build/git/python312/src/Python-3.12.12',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
